PCB Environment: /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/UI/Actions.hpp File Reference

PCB Environment 2

Loading...
Searching...
No Matches
Data Structures | Typedefs
Actions.hpp File Reference
`#include <future>`
`#include <set>`
`#include "UserSettings.hpp"`
`#include "Object.hpp"`
`#include "Track.hpp"`

Go to the source code of this file.

## Data Structures
class | ObjectPtrNameLessThan
class | UIActions
| WARNING: The non-async UIActions functions are expected to be non-concurrent. More...

## Typedefs
using | ComSet = std::set<Component *, ObjectPtrNameLessThan>
using | PinSet = std::set<Pin *, ObjectPtrNameLessThan>

## Typedef Documentation

## ◆ ComSet

using ComSet = std::set<Component *, ObjectPtrNameLessThan>

## ◆ PinSet

using PinSet = std::set<Pin *, ObjectPtrNameLessThan>